%%%%% Demo 1, posterior sparsity %%%%%

%% Data set

clear;
clc;
load demo1;

figure(1001)
clf
hold on

set(gca,'FontName','Helvetica')
set(gca,'FontSize',12)
plot(X(Y==1,1),X(Y==1,2),'ro','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','r');
plot(X(Y==3,1),X(Y==3,2),'bs','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','b');
plot(X(Y==0,1),X(Y==0,2),'kd','MarkerSize',3,'LineWidth',2,'MarkerFaceColor','k');
plot(XT(:,1),XT(:,2),'go','MarkerSize',3,'LineWidth',2,'MarkerFaceColor','g');
plot(X(Y==1,1),X(Y==1,2),'ro','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','r');
plot(X(Y==3,1),X(Y==3,2),'bs','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','b');
legend('Labeled A','Labeled B','Unlabeled data','Test data',3);
legend boxoff;
axis equal;
set(gca,'xtick',[]);
set(gca,'ytick',[]);

hold off
set(gcf,'PaperUnits','centimeters');
set(gcf,'PaperPosition',[0 0 12 12]);
print -depsc 2Moons_Data

%% Euclidean

load demo1;

N = size(XT,1);
YY = zeros(N,1);
for i=1:N
	if(Y(i)==0)
        YY(i)=oneNN(XT(i,:),X,Y,eye(2));
	end
end

figure(1002)
clf
hold on

set(gca,'FontName','Helvetica')
set(gca,'FontSize',12)
plot(X(Y==1,1),X(Y==1,2),'ro','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','r');
plot(X(Y==3,1),X(Y==3,2),'bs','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','b');
plot(XT(YY==1,1),XT(YY==1,2),'r+','MarkerSize',10);
plot(XT(YY==3,1),XT(YY==3,2),'bx','MarkerSize',10);
plot(X(Y==1,1),X(Y==1,2),'ro','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','r');
plot(X(Y==3,1),X(Y==3,2),'bs','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','b');
legend('Labeled A','Labeled B','Predicted A','PredictedB',3);
legend boxoff;
axis equal;
set(gca,'xtick',[]);
set(gca,'ytick',[]);

hold off
set(gcf,'PaperUnits','centimeters');
set(gcf,'PaperPosition',[0 0 12 12]);
print -depsc 2Moons_EUC

%% Maxent, projection

clear;
clc;
load demo1;

N = size(X,1);
[S D] = constructSD(Y);
nLabeled = sum(sum(S+D))/2;
nUnlabeled = N*(N-1)/2-nLabeled;
mu = nLabeled/nUnlabeled;
A = solver_GP(1, 0, 0, X, S, D);

P = getProjection(A, 2);
X = X*P';
XT = XT*P';
X = [X(:,2) X(:,1)];
XT = [XT(:,2) XT(:,1)];

figure(1003)
clf
hold on

set(gca,'FontName','Helvetica')
set(gca,'FontSize',12)
plot(X(Y==1,1),X(Y==1,2),'ro','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','r');
plot(X(Y==3,1),X(Y==3,2),'bs','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','b');
plot(X(Y==0,1),X(Y==0,2),'kd','MarkerSize',3,'LineWidth',2,'MarkerFaceColor','k');
plot(X(Y==1,1),X(Y==1,2),'ro','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','r');
plot(X(Y==3,1),X(Y==3,2),'bs','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','b');
axis equal;
set(gca,'xtick',[]);
set(gca,'ytick',[]);

hold off
set(gcf,'PaperUnits','centimeters');
set(gcf,'PaperPosition',[0 0 12 12]);
print -depsc 2Moons_MaxentP

%% Maxent, classification

load demo1;

N = size(XT,1);
YY = zeros(N,1);
for i=1:N
	if(Y(i)==0)
        YY(i)=oneNN(XT(i,:),X,Y,A);
	end
end

figure(1004)
clf
hold on

set(gca,'FontName','Helvetica')
set(gca,'FontSize',12)
plot(X(Y==1,1),X(Y==1,2),'ro','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','r');
plot(X(Y==3,1),X(Y==3,2),'bs','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','b');
plot(XT(YY==1,1),XT(YY==1,2),'r+','MarkerSize',10);
plot(XT(YY==3,1),XT(YY==3,2),'bx','MarkerSize',10);
plot(X(Y==1,1),X(Y==1,2),'ro','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','r');
plot(X(Y==3,1),X(Y==3,2),'bs','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','b');
axis equal;
set(gca,'xtick',[]);
set(gca,'ytick',[]);

hold off
set(gcf,'PaperUnits','centimeters');
set(gcf,'PaperPosition',[0 0 12 12]);
print -depsc 2Moons_MaxentC

%% SERAPH, projection

clear;
clc;
load demo1;

N = size(X,1);
[S D] = constructSD(Y);
nLabeled = sum(sum(S+D))/2;
nUnlabeled = N*(N-1)/2-nLabeled;
mu = nLabeled/nUnlabeled;
A = solver_GP(1, 100*mu, 0, X, S, D);

P = getProjection(A, 2);
X = X*P';
XT = XT*P';
X = [X(:,2) X(:,1)];
XT = [XT(:,2) XT(:,1)];

figure(1005)
clf
hold on

set(gca,'FontName','Helvetica')
set(gca,'FontSize',12)
plot(X(Y==1,1),X(Y==1,2),'ro','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','r');
plot(X(Y==3,1),X(Y==3,2),'bs','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','b');
plot(X(Y==0,1),X(Y==0,2),'kd','MarkerSize',3,'LineWidth',2,'MarkerFaceColor','k');
plot(X(Y==1,1),X(Y==1,2),'ro','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','r');
plot(X(Y==3,1),X(Y==3,2),'bs','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','b');
axis equal;
set(gca,'xtick',[]);
set(gca,'ytick',[]);

hold off
set(gcf,'PaperUnits','centimeters');
set(gcf,'PaperPosition',[0 0 12 12]);
print -depsc 2Moons_SeraphP

%% SERAPH, classification

load demo1;

N = size(XT,1);
YY = zeros(N,1);
for i=1:N
	if(Y(i)==0)
        YY(i)=oneNN(XT(i,:),X,Y,A);
	end
end

figure(1006)
clf
hold on

set(gca,'FontName','Helvetica')
set(gca,'FontSize',12)
plot(X(Y==1,1),X(Y==1,2),'ro','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','r');
plot(X(Y==3,1),X(Y==3,2),'bs','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','b');
plot(XT(YY==1,1),XT(YY==1,2),'r+','MarkerSize',10);
plot(XT(YY==3,1),XT(YY==3,2),'bx','MarkerSize',10);
plot(X(Y==1,1),X(Y==1,2),'ro','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','r');
plot(X(Y==3,1),X(Y==3,2),'bs','MarkerSize',10,'LineWidth',3,'MarkerFaceColor','b');
axis equal;
set(gca,'xtick',[]);
set(gca,'ytick',[]);

hold off
set(gcf,'PaperUnits','centimeters');
set(gcf,'PaperPosition',[0 0 12 12]);
print -depsc 2Moons_SeraphC
